# synonymset

## Description

This project is designed to replace synonyms with one word in a given text. It uses a comprehensive thesaurus to identify synonyms and replace them with a preferred word.
Also, includes russian and ukranian languages.
